New Feature

skill-meta folder
	- This folder used save the skill meta file to describe each skill
	
Skill-meta/skill folder
	- Skill-meta.md
		○ The meta file describe the input, output, the instructions and the acceptance criteria
		○ The acceptance criteria should follow MoSCoW principle and keep updated by catching failing cases from lesson and learn
		○ Skill meta should have a template.
Skill-meta/skill folder/candidate
		○ Skill will be generated by skill creator skills
Skill-meta/skill folder/test-{timestamp}
		○ Test case will be generated by skill creator skills
Skill-meta/skill folder/test-{timestamp}/result
		○ Test result generated by candidate skill

Lesson and Learned
	- Reflection can be used to continuously improve the skill
		○ For each skill we need have lesson and learned file to recording the error, issue or human feedback for improvements
		


Change to Existing Skill

Skill creator
	- Skill preparation
		○ Create a skill-meta.md template in this skill, you can research what is important for create/update for SKILL, **important skill-meta.md is used for agent as a specification to create SKILL**
		○ skill-meta.md can have 3 types one for task-type, one for tools, one for board management.
		○ Create a test-case.md template in this skill, you can research what is important for testing SKILL, **important test-case.md is used for agent as a test script to validate SKILL**
		○ All the templates here should focus on agent readable instead of human.
	
	- If no candidate skill exists
	- When create skill
		○ Sub-agent 1: base on under understanding to create skill-meta.md under x-ipe-docs/skill-meta/skill folder base on the skill-meta template
		○ Sub-agent 2: to follow existing rule to create a skill draft under x-ipe-docs/skill-meta/skill folder/candidate/ (support all skill capabilities, such as template, reference, scripts etc.)
		○ Sub-agent 3 depends on Sub-agent 1: Leverage skill-meta to reflect candidate skill and make improve to it.
		○ Sub-agent 4 depends on Sub-agent 1: Generate test cases base on acceptance criteria from skill-meta put in /test-{timestamp}
		○ Sub-agent 5 depends on Sub-agent 3 and 4: use skill from candidate to run the test cases, if any test result required save the result to x-ipe-docs/skill-meta/skill folder/test-{timestamp}/result
		○ Sub-agent 6 depends on Sub-agent 5: Base on the test case to evaluate the result see if it's passed. Return test evaluation and improvement tips if needed
		○ Depends on Sub-agent 6: Main Agent base on test evaluation to decide if create a skill in skill folder or not
		○ Try to run parallel
		○ 
		
	- When update skill
		○ Sub-agent 1: base on the user input or x-ipe-meta-lesson-learned.md under x-ipe-docs/skill-meta/skill folder to understand the main points. Then analyze skill meta. If any gap, for each of them in lesson and learned we need have captured scenario, ground truth(from correct result after failure or mistake) add them into acceptance criteria in skill-meta.md, if any question ask user for feedback. 
		○ Sub-agent 2: Having another sub-agent to follow base on the user input and x-ipe-meta-lesson-learned.md to update candidate skill
		○ Sub-agent 3 depends on Sub-agent 1: Leverage skill-meta to reflect candidate skill and make improve to it.
		○ Sub-agent 4 depends on Sub-agent 1: Generate test cases base on acceptance criteria from skill-meta put in /test-{timestamp}
		○ Sub-agent 5 depends on Sub-agent 3 and 4: use skill from candidate to run the test cases, if any test result required save the result to x-ipe-docs/skill-meta/skill folder/test-{timestamp}/result
		○ Sub-agent 6 depends on Sub-agent 5: Base on the test case to evaluate the result see if it's passed. Return test evaluation and improvement tips if needed
		○ Depends on Sub-agent 6: Main Agent base on test evaluation to decide if create a skill in skill folder or not
		○ Try to run parallel

New skill to be introduced

Lesson-Learned Skill
	- Skill preparation
		○ Create a x-ipe-meta-lesson-learned.md template in this skill, you can research what is important feedbacks required for SKILL update, **important x-ipe-meta-lesson-learned.md is used for agent to know what should be updated for SKILL in skill meta**
		○ All the templates here should focus on agent readable instead of human.
		
	- Skill execution
		○ When it's called, learn from the context what happens, what skill in skill meta has been used. Mainly focus on issues and user feedbacks to generate a summary of skill, skill issue or human feedbacks
		○ Having sub-agent to each skill, base on the summary and skill-meta.md to learn what's the gap, and having them noted in x-ipe-meta-lesson-learned.md
	
	

